From: Sven Eckelmann <s...@narfation.org>

The routing checks are validating the source mac address of the outer
ethernet header. They reject every source mac address which is a broadcast
address. But they also have to reject any multicast mac addresses.

Signed-off-by: Sven Eckelmann <s...@narfation.org>
[s...@simonwunderlich.de: fix commit message typo]
Signed-off-by: Simon Wunderlich <s...@simonwunderlich.de>
---
 net/batman-adv/routing.c | 12 ++++++------
 1 file changed, 6 insertions(+), 6 deletions(-)

diff --git a/net/batman-adv/routing.c b/net/batman-adv/routing.c
index 105d4fc..c02897b 100644
--- a/net/batman-adv/routing.c
+++ b/net/batman-adv/routing.c
@@ -368,8 +368,8 @@ int batadv_recv_icmp_packet(struct sk_buff *skb,
        if (is_broadcast_ether_addr(ethhdr->h_dest))
                goto free_skb;
 
-       /* packet with broadcast sender address */
-       if (is_broadcast_ether_addr(ethhdr->h_source))
+       /* packet with broadcast/multicast sender address */
+       if (is_multicast_ether_addr(ethhdr->h_source))
                goto free_skb;
 
        /* not for me */
@@ -466,8 +466,8 @@ static int batadv_check_unicast_packet(struct batadv_priv 
*bat_priv,
        if (is_broadcast_ether_addr(ethhdr->h_dest))
                return -EBADR;
 
-       /* packet with broadcast sender address */
-       if (is_broadcast_ether_addr(ethhdr->h_source))
+       /* packet with broadcast/multicast sender address */
+       if (is_multicast_ether_addr(ethhdr->h_source))
                return -EBADR;
 
        /* not for me */
@@ -1159,8 +1159,8 @@ int batadv_recv_bcast_packet(struct sk_buff *skb,
        if (!is_broadcast_ether_addr(ethhdr->h_dest))
                goto free_skb;
 
-       /* packet with broadcast sender address */
-       if (is_broadcast_ether_addr(ethhdr->h_source))
+       /* packet with broadcast/multicast sender address */
+       if (is_multicast_ether_addr(ethhdr->h_source))
                goto free_skb;
 
        /* ignore broadcasts sent by myself */
-- 
2.10.1

Reply via email to